import React from "react"

import { Button, Card, Carousel } from "@onegeo-suite/gatsby-theme-onegeo"
import Image from "./core/Image"
import cx from "classix"
import { merge } from "../utils"

interface Service {
    name: string
    description: string
    image: string
    url: string
    option: any
}

interface Bg {
    src: string
}
interface Props {
    services?: Array<Service>
    bgImage?: Array<Bg>
    size?: "xs" | "base" | "xl" | "full"
    options?: any
}

const HeroTile = (props: Props) => {
    // Data structure (default value)
    const {
        services,
        bgImage = [
            {
                src: "https://picsum.photos/1920/600?random=1",
            },
            {
                src: "https://picsum.photos/1920/600?random=2",
            },
            {
                src: "https://picsum.photos/1920/600?random=3",
            },
        ],
        size = "base",
    } = props

    const options = props.options ?? {}
    let imageFondList, imageFond

    if (bgImage.length > 1) {
        imageFondList = bgImage
        imageFond = [
            imageFondList.map((image: any) => {
                return image
            }),
        ]
    } else {
        imageFond = bgImage[0]
    }
    return (
        <div
            className={cx(
                "relative flex h-full flex-col justify-center bg-cover bg-center",
                size == "base" ? "h-[60vh]" : "",
                size == "xl" ? "h-[75vh]" : "",
                size == "xs" ? "h-[50vh]" : ""
            )}
        >
            {bgImage?.length > 1 && (
                <Carousel
                    height={`${size == "base" ? "h-[60vh]" : ""} ${
                        size == "xl" ? "h-[75vh]" : ""
                    } ${size == "xs" ? "h-[50vh]" : ""}`}
                    images={imageFond[0]}
                    animation="fade"
                    delay={3000}
                />
            )}
            {bgImage?.length === 1 && (
                <Image
                    image={bgImage[0].src}
                    className={cx(
                        "w-full",
                        size == "base" ? "h-[60vh]" : "",
                        size == "xl" ? "h-[75vh]" : "",
                        size == "xs" ? "h-[50vh]" : ""
                    )}
                    objectPosition="top"
                />
            )}
            {/*  */}
            <div className="absolute top-0 z-10 h-full w-full from-slate-500 opacity-80"></div>

            <div className="absolute z-10 grid h-full w-full grid-cols-1 sm:grid-cols-2 lg:grid-cols-4">
                {services &&
                    services.map((service, idx) => {
                        return (
                            <Card
                                key={idx}
                                layout="top"
                                size="full"
                                anime={false}
                                {...service}
                                options={merge(
                                    {
                                        class: {
                                            main: "card-side sm:flex-col shadow-none bg-transparent opacity-90 sm:pt-10 lg:pt-40 group/card transition duration-200 ease-out hover:bg-base-100 ",
                                            body: "self-center text-base-100 group-hover/card:text-base-content lg:transition lg:duration-200 ease-in-out lg:group-hover/card:-translate-y-6",
                                            figure: "lg:transition lg:duration-200 ease-in-out lg:group-hover/card:-translate-y-6",
                                            image: "m-auto w-40 h-24 md:h-32 lg:h-40 ",
                                            imageComponent: "object-scale-down",
                                            title: "sm:justify-center text-xl lg:text-2xl",
                                            description:
                                                " hidden lg:block text-xl text-center opacity-0 lg:transition lg:duration-200 ease-out lg:group-hover/card:opacity-100",
                                            __for_inline_svg:
                                                "h-full w-full fill-slate-50 group-hover/card:fill-sky-700",
                                        },
                                    },
                                    merge(options?.card, service?.options)
                                )}
                            />
                        )
                    })}
            </div>
        </div>
    )
}

export default HeroTile
